<template>
  <a-card :bordered="false">

    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">

          <a-col
            :xl="6"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <a-form-item label="删除标记">
              <a-input
                placeholder="请输入删除标记"
                v-model="queryParam.delFlag"
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col
            :xl="6"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <a-form-item label="领用单编码">
              <a-input
                placeholder="请输入领用单编码"
                v-model="queryParam.receiveCode"
              ></a-input>
            </a-form-item>
          </a-col>
          <template v-if="toggleSearchStatus">
            <a-col
              :xl="6"
              :lg="7"
              :md="8"
              :sm="24"
            >
              <a-form-item label="领用人">
                <a-input
                  placeholder="请输入领用人"
                  v-model="queryParam.receiveUser"
                ></a-input>
              </a-form-item>
            </a-col>
            <a-col
              :xl="6"
              :lg="7"
              :md="8"
              :sm="24"
            >
              <a-form-item label="领用事由">
                <a-input
                  placeholder="请输入领用事由"
                  v-model="queryParam.receiveReason"
                ></a-input>
              </a-form-item>
            </a-col>
            <a-col
              :xl="6"
              :lg="7"
              :md="8"
              :sm="24"
            >
              <a-form-item label="领用状态">
                <a-input
                  placeholder="请输入领用状态"
                  v-model="queryParam.receiveStatus"
                ></a-input>
              </a-form-item>
            </a-col>
          </template>
          <a-col
            :xl="6"
            :lg="7"
            :md="8"
            :sm="24"
          >
            <span
              style="float: left;overflow: hidden;"
              class="table-page-search-submitButtons"
            >
              <a-button
                type="primary"
                @click="searchQuery"
                icon="search"
              >查询</a-button>
              <a-button
                type="primary"
                @click="searchReset"
                icon="reload"
                style="margin-left: 8px"
              >重置</a-button>
              <a
                @click="handleToggleSearch"
                style="margin-left: 8px"
              >
                {{ toggleSearchStatus ? '收起' : '展开' }}
                <a-icon :type="toggleSearchStatus ? 'up' : 'down'" />
              </a>
            </span>
          </a-col>

        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button
        @click="handleAdd"
        type="primary"
        icon="plus"
      >新增</a-button>
      <a-button
        type="primary"
        icon="download"
        @click="handleExportXls('备品备件领用单')"
      >导出</a-button>
      <a-upload
        name="file"
        :showUploadList="false"
        :multiple="false"
        :headers="tokenHeader"
        :action="importExcelUrl"
        @change="handleImportExcel"
      >
        <a-button
          type="primary"
          icon="import"
        >导入</a-button>
      </a-upload>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item
            key="1"
            @click="batchDel"
          ><a-icon type="delete" />删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class="ant-alert ant-alert-info"
        style="margin-bottom: 16px;"
      >
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a
          style="margin-left: 24px"
          @click="onClearSelected"
        >清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange"
      >

        <span
          slot="action"
          slot-scope="text, record"
        >
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a-popconfirm
                  title="确定删除吗?"
                  @confirm="() => handleDelete(record.id)"
                >
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>
    <!-- table区域-end -->

    <!-- 表单区域 -->
    <eamSparePartReceive-modal
      ref="modalForm"
      @ok="modalFormOk"
    ></eamSparePartReceive-modal>
  </a-card>
</template>

<script>
import '@assets/less/TableExpand.less'
import EamSparePartReceiveModal from './modules/EamSparePartReceive/EamSparePartReceiveModal.vue'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'

export default {
  name: "EamSparePartReceiveList",
  mixins: [JeecgListMixin],
  components: {
    EamSparePartReceiveModal
  },
  data() {
    return {
      description: '备品备件领用单管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '删除标记',
          align: "center",
          dataIndex: 'delFlag'
        },
        {
          title: '领用单编码',
          align: "center",
          dataIndex: 'receiveCode'
        },
        {
          title: '领用人',
          align: "center",
          dataIndex: 'receiveUser'
        },
        {
          title: '领用事由',
          align: "center",
          dataIndex: 'receiveReason'
        },
        {
          title: '领用状态',
          align: "center",
          dataIndex: 'receiveStatus'
        },
        {
          title: '是否需要归还;是：存在归还动作，否：直接完成',
          align: "center",
          dataIndex: 'giveBackFlag'
        },
        {
          title: '审核人',
          align: "center",
          dataIndex: 'approvalUser'
        },
        {
          title: '审核时间',
          align: "center",
          dataIndex: 'approvalTime'
        },
        {
          title: '备注',
          align: "center",
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: "center",
          scopedSlots: { customRender: 'action' },
        }
      ],
      url: {
        list: "/eam/eamSparePartReceive/list",
        delete: "/eam/eamSparePartReceive/delete",
        deleteBatch: "/eam/eamSparePartReceive/deleteBatch",
        exportXlsUrl: "eam/eamSparePartReceive/exportXls",
        importExcelUrl: "eam/eamSparePartReceive/importExcel",
      },
    }
  },
  computed: {
    importExcelUrl: function () {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
    }
  },
  methods: {

  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>